import{d as t,o,K as s,b as a,u as r,br as _,Q as c}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="41389e02-63d1-40dc-83d6-7ac86d4d2f3f",e._sentryDebugIdIdentifier="sentry-dbid-41389e02-63d1-40dc-83d6-7ac86d4d2f3f")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,d)=>(o(),s("div",i,[a(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.7c1e2c53.js.map
