import{P as f}from"./PlayerNavbar.12da8729.js";import{d as g,e3 as h,e4 as c,f as b,g as y,r as k,K as v,u as n,c as w,F as L,a as C,b as I,o as i,Q as N}from"./index.f8cd7fc7.js";import{u as V}from"./workspaceStore.ad71991a.js";import"./userStore.d326fa43.js";import"./metadata.3739f485.js";import"./PhWebhooksLogo.vue.6e7d20ff.js";import"./LoadingOutlined.fc3e4e7e.js";import"./PhSignOut.vue.0eeaecf7.js";import"./index.52edb435.js";import"./Avatar.427dc6c7.js";import"./url.f92805c8.js";import"./colorHelpers.58a1d2b7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="6df95629-a491-449c-9ac3-31f2baa08b3b",o._sentryDebugIdIdentifier="sentry-dbid-6df95629-a491-449c-9ac3-31f2baa08b3b")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,a=b(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(f,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const z=N(D,[["__scopeId","data-v-f095bece"]]);export{z as default};
//# sourceMappingURL=Main.09fb1cac.js.map
