import{P as r}from"./record.89b5c58a.js";import{e as d,f as a}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d4d4db0e-bc3e-4379-b42b-843ee16ae26e",e._sentryDebugIdIdentifier="sentry-dbid-d4d4db0e-bc3e-4379-b42b-843ee16ae26e")}catch{}})();const c=new r,i=d("omniChat",()=>{const e=a(!1),t=a(!1),n=()=>{t.value=!0},s=()=>{t.value=!1},o=()=>{e.value=!0,n()},u=()=>{e.value=!1,s()};return{isOpen:e,isInputFocused:t,focusInput:n,blurInput:s,open:o,close:u,toggle:()=>{e.value?u():o()}}});export{c as o,i as u};
//# sourceMappingURL=omniChatStore.ef327d23.js.map
