import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.eccae6dc.js";import{d as m,e3 as f,e4 as b,K as g,b as y,u as a,o as w,Q as k}from"./index.f8cd7fc7.js";import{u as h}from"./workspaceStore.ad71991a.js";import"./userStore.d326fa43.js";import"./CircularLoading.4b50f901.js";import"./Logo.4e3c3806.js";import"./string.e821e86d.js";import"./index.53fa2135.js";import"./url.f92805c8.js";import"./colorHelpers.58a1d2b7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f3097386-0c85-4752-8fce-b556149bc6e5",e._sentryDebugIdIdentifier="sentry-dbid-f3097386-0c85-4752-8fce-b556149bc6e5")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:s,...n}=t.query;if(s){await o.push({path:s,query:n,params:t.params});return}o.push({name:"playerHome",query:n})};return(s,n)=>{var c,p,u,i,d;return w(),g("div",v,[y(l,{"logo-url":(p=(c=a(r).state.workspace)==null?void 0:c.logoUrl)!=null?p:void 0,"brand-name":(u=a(r).state.workspace)==null?void 0:u.brandName,locale:(d=(i=a(r).state.workspace)==null?void 0:i.language)!=null?d:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-cb33c596"]]);export{H as default};
//# sourceMappingURL=Login.f289c23e.js.map
