import{m as a,n,T as r,p as o,P as d,C as p,M as c,s as f,q as s,t as m,v as b,x as u,y as g}from"./index.f8cd7fc7.js";import{s as y}from"./userStore.d326fa43.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.e3f925bb.js";import{a as i}from"./workspaceStore.ad71991a.js";import"./PlayerConfigProvider.407d7a4f.js";import"./colorHelpers.58a1d2b7.js";import"./index.305b393a.js";import"./url.f92805c8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f5ae1852-174b-48cd-beab-b92d2b1601fe",t._sentryDebugIdIdentifier="sentry-dbid-f5ae1852-174b-48cd-beab-b92d2b1601fe")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=a(),e=n({render:()=>m(l)});r.init(),o(e,i),w.init(),e.use(i),e.use(t),e.use(d),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",c),e.component("Message",f),s(e,b),s(e,u),s(e,g)})();
//# sourceMappingURL=player.ec79b641.js.map
