import{i as h}from"./metadata.3739f485.js";import{W as k}from"./Watermark.f80a4cfe.js";import{F as w}from"./PhArrowSquareOut.vue.9d7950df.js";import{d as v,e3 as b,g as x,f as C,u as e,K as m,b as p,w as r,F as z,o as t,c as n,az as f,d2 as y,aL as D,ea as I,da as _,eh as F,eb as L,ec as T,Q as B}from"./index.f8cd7fc7.js";import{u as H}from"./workspaceStore.ad71991a.js";import"./index.f5262547.js";import{L as N}from"./LoadingOutlined.fc3e4e7e.js";import{C as S}from"./Card.1e7a4e39.js";import"./PhWebhooksLogo.vue.6e7d20ff.js";import"./userStore.d326fa43.js";import"./url.f92805c8.js";import"./colorHelpers.58a1d2b7.js";import"./TabPane.aa07834e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="5c52d538-0eca-4a2e-95f3-96d4715a48e2",o._sentryDebugIdIdentifier="sentry-dbid-5c52d538-0eca-4a2e-95f3-96d4715a48e2")}catch{}})();const V={key:0,class:"home-container"},W=v({__name:"Home",setup(o){const i=b(),l=H(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),g=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(t(),m("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(t(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(t(!0),m(D,{key:1},I(u.value,a=>(t(),n(e(S),{key:a.id,class:T(["form-card",{loading:c.value===a.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(a.path,a.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(t(),n(F(e(h)(a.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(L(a.name),1)]),_:2},1024),c.value!==a.id?(t(),n(e(w),{key:0,size:"20"})):(t(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(k,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):z("",!0)}});const X=B(W,[["__scopeId","data-v-060376d1"]]);export{X as default};
//# sourceMappingURL=Home.2e7a74d0.js.map
