import{O as r}from"./userStore.d326fa43.js";import{d as l,J as i,K as u,b as a,w as n,u as d,o as f,az as o,d6 as c,d5 as _}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e16d8daf-471f-415b-9642-50520fda1933",e._sentryDebugIdIdentifier="sentry-dbid-e16d8daf-471f-415b-9642-50520fda1933")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(f(),u("div",null,[a(d(c),null,{default:n(()=>[o("You're authenticated")]),_:1}),a(d(_),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.79612d5a.js.map
