import{L as t}from"./Logo.4e3c3806.js";import{d as n,o as r,c as d,u as f}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="e5b4e48d-f327-46ca-9eaa-efe1e118ac9f",e._sentryDebugIdIdentifier="sentry-dbid-e5b4e48d-f327-46ca-9eaa-efe1e118ac9f")}catch{}})();const i="/assets/logo.0faadfa2.svg",u=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(a,o)=>{var s;return r(),d(t,{"image-url":f(i),"brand-name":"Abstra","hide-text":a.hideText,size:(s=a.size)!=null?s:"small"},null,8,["image-url","hide-text","size"])}}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.62cc75bb.js.map
