import{d as n,K as s,a as d,O as a,ec as c,o as r,Q as l}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="486dfd75-0200-4449-b6fc-7cb46cc90bbb",e._sentryDebugIdIdentifier="sentry-dbid-486dfd75-0200-4449-b6fc-7cb46cc90bbb")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(r(),s("div",_,[d("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[a(t.$slots,"default",{},void 0,!0)],2)]))}});const i=l(u,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.ab469395.js.map
