import{G as s,dv as c,dw as i}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="afd1ff12-6bc4-4271-940d-8ee6d7ba8de9",e._sentryDebugIdIdentifier="sentry-dbid-afd1ff12-6bc4-4271-940d-8ee6d7ba8de9")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:d,RangePicker:a}=c(i),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(t.name,t),e.component(d.name,d),e)});export{u as D,r as M,d as Q,a as R,t as W};
//# sourceMappingURL=dayjs.0bc3467c.js.map
