import{Q as c,o,K as d,O as s,a as n,F as a}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c8d12bec-3fbb-4bda-ad4e-c625c437dad6",e._sentryDebugIdIdentifier="sentry-dbid-c8d12bec-3fbb-4bda-ad4e-c625c437dad6")}catch{}})();const r={},i={class:"base-layout"},f={class:"base-middle"},_={class:"content"},l={class:"left"},u={key:0,class:"base-footer"},b={key:0};function y(e,t){return o(),d("div",i,[s(e.$slots,"sidebar",{},void 0,!0),n("section",f,[s(e.$slots,"navbar",{},void 0,!0),n("section",_,[n("section",l,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),d("section",u,[s(e.$slots,"footer",{},void 0,!0)])):a("",!0)]),e.$slots.chat?(o(),d("section",b,[s(e.$slots,"chat",{},void 0,!0)])):a("",!0)])])])}const g=c(r,[["render",y],["__scopeId","data-v-fe23e6dd"]]);export{g as B};
//# sourceMappingURL=BaseLayout.e6a81dd7.js.map
