import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.7d0c3e83.js";import{R as f}from"./tasksController.cc58ec8d.js";import{d as b,e4 as _,g,K as y,b as w,w as k,u as n,c as I,F as T,aL as v,o as c,az as B,d6 as j}from"./index.f8cd7fc7.js";import"./gateway.2a9fa462.js";import{a as x,B as C}from"./build.0b160679.js";import{a as D}from"./project.adcc030f.js";import"./columns.e632bef5.js";import{a as R}from"./asyncComputed.57e338d8.js";import"./metadata.3739f485.js";import"./PhWebhooksLogo.vue.6e7d20ff.js";import"./ant-design.b5fe3672.js";import"./string.e821e86d.js";import"./index.016130f1.js";import"./dayjs.0bc3467c.js";import"./linters.9e909d26.js";import"./scripts.4c57ae51.js";import"./record.89b5c58a.js";import"./polling.9435ea7c.js";import"./popupNotifcation.6f672802.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="8ae0399c-c557-422c-bdcb-a59c9210e99a",e._sentryDebugIdIdentifier="sentry-dbid-8ae0399c-c557-422c-bdcb-a59c9210e99a")}catch{}})();const U=b({__name:"Tasks",setup(e){const a=_().params.projectId,l=new f(a),{result:o}=R(async()=>{const r=(await x.list(a)).find(d=>d.latest);if(!r)return null;const[p,u]=await Promise.all([C.get(r.id),D.get(a)]);return{buildSpec:p,project:u}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(c(),y(v,null,[w(n(j),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(c(),I(m,{key:0,class:"tasks",api:n(l),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.8ce43f53.js.map
