import{_ as c}from"./TasksView.vue_vue_type_script_setup_true_lang.7d0c3e83.js";import{L as f}from"./tasksController.cc58ec8d.js";import{d as p,f as u,c as _,w as t,o as m,b as s,u as o,d6 as b,az as i,bM as y,da as k,Q as w}from"./index.f8cd7fc7.js";import{C as g}from"./ContentLayout.ab469395.js";import{a as T}from"./ant-design.b5fe3672.js";import"./metadata.3739f485.js";import"./PhWebhooksLogo.vue.6e7d20ff.js";import"./string.e821e86d.js";import"./index.016130f1.js";import"./dayjs.0bc3467c.js";import"./gateway.2a9fa462.js";import"./popupNotifcation.6f672802.js";import"./linters.9e909d26.js";import"./asyncComputed.57e338d8.js";import"./scripts.4c57ae51.js";import"./record.89b5c58a.js";import"./polling.9435ea7c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="63b454b0-5a4b-4bd8-a630-6fdd8fd5c20d",e._sentryDebugIdIdentifier="sentry-dbid-63b454b0-5a4b-4bd8-a630-6fdd8fd5c20d")}catch{}})();const x=p({__name:"Tasks",setup(e){const a=new f,r=u(null);async function l(){var n;await T("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(d,n)=>(m(),_(g,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(b),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(y),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(c,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const $=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{$ as default};
//# sourceMappingURL=Tasks.977991a9.js.map
