import{O as d}from"./userStore.d326fa43.js";import{d as l,J as c,K as u,b as a,w as n,u as o,o as i,az as s,d6 as f,d5 as b}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f8cc8c98-317c-4869-b5e1-6167b90284f3",e._sentryDebugIdIdentifier="sentry-dbid-f8cc8c98-317c-4869-b5e1-6167b90284f3")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new d().logoutCallback()}),(t,r)=>(i(),u("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.430306de.js.map
