import{C as p}from"./controller.55d4b44c.js";import{d as i,e4 as n,c as s,u as m,o as d}from"./index.f8cd7fc7.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.b48a5fdb.js";import"./gateway.2a9fa462.js";import"./popupNotifcation.6f672802.js";import"./fetch.e588e7da.js";import"./record.89b5c58a.js";import"./PhPencil.vue.61a31909.js";import"./SaveButton.535e82be.js";import"./UnsavedChangesHandler.1fbbd94a.js";import"./ExclamationCircleOutlined.a1686d31.js";import"./CrudView.2e1c5ca0.js";import"./router.a76e8604.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b64ebf34.js";import"./url.f92805c8.js";import"./PhDotsThreeVertical.vue.f6f771e3.js";import"./Badge.cf0f74ab.js";import"./index.a3fcd32d.js";import"./index.016130f1.js";import"./asyncComputed.57e338d8.js";import"./polling.9435ea7c.js";import"./omniChatStore.ef327d23.js";import"./index.53fa2135.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="edf86745-70c2-4d97-9d9f-9f4591c5e62c",o._sentryDebugIdIdentifier="sentry-dbid-edf86745-70c2-4d97-9d9f-9f4591c5e62c")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(a,f)=>(d(),s(c,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.1293a087.js.map
