import"./App.vue_vue_type_style_index_0_lang.e3f925bb.js";import{_ as y}from"./App.vue_vue_type_style_index_0_lang.e3f925bb.js";import"./userStore.d326fa43.js";import"./index.f8cd7fc7.js";import"./PlayerConfigProvider.407d7a4f.js";import"./colorHelpers.58a1d2b7.js";import"./index.305b393a.js";import"./workspaceStore.ad71991a.js";import"./url.f92805c8.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="25aa32d4-755f-4173-891d-1db973d4bb9a",d._sentryDebugIdIdentifier="sentry-dbid-25aa32d4-755f-4173-891d-1db973d4bb9a")}catch{}})();export{y as default};
//# sourceMappingURL=App.387eede0.js.map
