import{O as s,R as a}from"./OmniChat.0c0bcfe3.js";import{d as i,e4 as c,o as d,c as f,u as n}from"./index.f8cd7fc7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="11a08060-b7fd-4f17-ab76-8eebf761abeb",e._sentryDebugIdIdentifier="sentry-dbid-11a08060-b7fd-4f17-ab76-8eebf761abeb")}catch{}})();const y=i({__name:"ConsoleOmniChat",setup(e){const t=c().params.projectId,r=new a(t);return(p,u)=>(d(),f(s,{"ai-chat-repository":n(r),environment:{origin:"console",projectId:n(t)}},null,8,["ai-chat-repository","environment"]))}});export{y as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.941e682d.js.map
