import{B as m}from"./BaseLayout.e6a81dd7.js";import{d as a,e4 as n,r as s,c,w as r,o as d,b as i,u}from"./index.f8cd7fc7.js";import{N as b,_ as f}from"./Navbar.36314973.js";import"./OmniChat.0c0bcfe3.js";import"./gateway.2a9fa462.js";import"./popupNotifcation.6f672802.js";import"./AbstraLogo.vue_vue_type_script_setup_true_lang.62cc75bb.js";import"./Logo.4e3c3806.js";import"./uuid.d0ac23b4.js";import"./PhClockCounterClockwise.vue.c66999e3.js";import"./omniChatStore.ef327d23.js";import"./record.89b5c58a.js";import"./LoadingOutlined.fc3e4e7e.js";import"./linters.9e909d26.js";import"./asyncComputed.57e338d8.js";import"./columns.e632bef5.js";import"./string.e821e86d.js";import"./controller.44dc2b13.js";import"./vue-flow-core.3eb4f74a.js";import"./validations.a8951eca.js";import"./metadata.3739f485.js";import"./PhWebhooksLogo.vue.6e7d20ff.js";import"./controller.55d4b44c.js";import"./fetch.e588e7da.js";import"./PhPencil.vue.61a31909.js";import"./requirements.ef472f3e.js";import"./scripts.4c57ae51.js";import"./PhCopySimple.vue.d9deeabd.js";import"./index.cf1aff0a.js";import"./Avatar.427dc6c7.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.c6b174d6.js";import"./PhArrowCounterClockwise.vue.7a4e84ce.js";import"./PhFilePy.vue.925a6880.js";import"./PhChats.vue.8c20cfc4.js";import"./PhRocket.vue.b94c574a.js";import"./PhPackage.vue.b73330a0.js";import"./workspaces.5c9ec6b9.js";import"./workspaceStore.ad71991a.js";import"./userStore.d326fa43.js";import"./url.f92805c8.js";import"./colorHelpers.58a1d2b7.js";import"./polling.9435ea7c.js";import"./PhArrowSquareOut.vue.9d7950df.js";import"./PhSignOut.vue.0eeaecf7.js";import"./PhSparkle.vue.1a46ba93.js";import"./editor.a8449fec.js";import"./index.a3fcd32d.js";import"./CloseCircleOutlined.d470f9b4.js";import"./CheckCircleFilled.e8f7da0a.js";import"./index.53fa2135.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="3695dc8d-3b8b-44b0-a2c0-ea19b658a0ec",t._sentryDebugIdIdentifier="sentry-dbid-3695dc8d-3b8b-44b0-a2c0-ea19b658a0ec")}catch{}})();const ut=a({__name:"Workspace",setup(t){const o=n();return(p,_)=>{const e=s("RouterView");return d(),c(m,null,{navbar:r(()=>[i(b,{"page-title":u(o).meta.title},null,8,["page-title"])]),content:r(()=>[i(e)]),chat:r(()=>[i(f)]),_:1})}}});export{ut as default};
//# sourceMappingURL=Workspace.dcb98b9b.js.map
