import{d as i,c as p,w as m,o as n,b as a,u as t}from"./index.f8cd7fc7.js";import"./linters.9e909d26.js";import{W as s}from"./workspaces.5c9ec6b9.js";import{C as d}from"./ContentLayout.ab469395.js";import{E as f}from"./controller.55d4b44c.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.b48a5fdb.js";import"./asyncComputed.57e338d8.js";import"./workspaceStore.ad71991a.js";import"./userStore.d326fa43.js";import"./url.f92805c8.js";import"./colorHelpers.58a1d2b7.js";import"./record.89b5c58a.js";import"./gateway.2a9fa462.js";import"./popupNotifcation.6f672802.js";import"./fetch.e588e7da.js";import"./PhPencil.vue.61a31909.js";import"./SaveButton.535e82be.js";import"./UnsavedChangesHandler.1fbbd94a.js";import"./ExclamationCircleOutlined.a1686d31.js";import"./CrudView.2e1c5ca0.js";import"./router.a76e8604.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b64ebf34.js";import"./PhDotsThreeVertical.vue.f6f771e3.js";import"./Badge.cf0f74ab.js";import"./index.a3fcd32d.js";import"./index.016130f1.js";import"./polling.9435ea7c.js";import"./omniChatStore.ef327d23.js";import"./index.53fa2135.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="02fa8073-6eba-40d2-885c-9fd9707c52f6",o._sentryDebugIdIdentifier="sentry-dbid-02fa8073-6eba-40d2-885c-9fd9707c52f6")}catch{}})();const J=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(n(),p(d,null,{default:m(()=>[a(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{J as default};
//# sourceMappingURL=EnvVarsEditor.0cca2e03.js.map
